OpenLP
======

You're probably reading this because you've just downloaded the source code for
OpenLP. If you are looking for the installer file, please go to the download
page on the web site:

    https://openlp.org/#download

If you're looking for how to contribute to OpenLP, then please look at the
OpenLP wiki:

    https://wiki.openlp.org/

Thanks for downloading OpenLP!
